"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _reactHelmet = require("react-helmet");
var _reactIntl = require("react-intl");
var _validationHelpers = require("../../../helpers/validationHelpers");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); } /* global window, FormData */
const messages = (0, _reactIntl.defineMessages)({
  title: {
    "id": "passwordResetRequestPage.title",
    "defaultMessage": "Reset Password"
  },
  prompt: {
    "id": "passwordResetRequestPage.prompt",
    "defaultMessage": "Please enter your email address to request a password reset."
  },
  email: {
    "id": "passwordResetRequestPage.email",
    "defaultMessage": "Email"
  },
  submit: {
    "id": "passwordResetRequestPage.submit",
    "defaultMessage": "Submit"
  },
  success: {
    "id": "passwordResetRequestPage.success",
    "defaultMessage": "An email has been sent to {email}. Follow the instructions in the email to finish resetting your password."
  },
  error: {
    "id": "passwordResetRequestPage.error",
    "defaultMessage": "An error occurred while attempting to request the password reset: {detail}"
  },
  errorNotFound: {
    "id": "passwordResetRequestPage.errorNotFound",
    "defaultMessage": "Could not find an account with the email {email}."
  },
  errorMissingEmail: {
    "id": "passwordResetRequestPage.errorMissingEmail",
    "defaultMessage": "Please enter an email address."
  },
  errorInvalidEmail: {
    "id": "passwordResetRequestPage.errorInvalidEmail",
    "defaultMessage": "{email} is not a valid email address."
  },
  errorSSORequired: {
    "id": "passwordResetRequestPage.errorSSORequired",
    "defaultMessage": "{email} is required to sign in using a single sign-on provider. The CollectionSpace account password cannot be reset."
  }
});
const propTypes = {
  csrf: _propTypes.default.object,
  tenantId: _propTypes.default.string,
  intl: _reactIntl.intlShape.isRequired
};
const defaultProps = {
  csrf: null,
  tenantId: null
};
function PasswordResetRequestPage(props) {
  const {
    csrf,
    intl,
    tenantId
  } = props;
  const [error, setError] = (0, _react.useState)();
  const [isPending, setPending] = (0, _react.useState)();
  const [success, setSuccess] = (0, _react.useState)();
  if (success) {
    return /*#__PURE__*/_react.default.createElement("p", {
      className: "status success"
    }, success);
  }
  const handleSubmit = event => {
    event.preventDefault();
    const form = event.target;
    const formData = new FormData(form);
    const email = formData.get('email');
    if (!email) {
      setError( /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.errorMissingEmail));
      return;
    }
    if (!(0, _validationHelpers.isValidEmail)(email)) {
      setError( /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.errorInvalidEmail, {
        values: {
          email
        }
      })));
      return;
    }
    const url = new URL(form.action);
    const params = url.searchParams;
    if (tenantId) {
      params.set('tid', tenantId);
    }
    params.set('email', email);
    if (csrf) {
      params.set(csrf.parameterName, csrf.token);
    }
    setError(null);
    setPending(true);
    window.fetch(url, {
      method: 'POST'
    }).then(response => Promise.all([response, response.text()])).then(([response, text]) => {
      if (response.ok) {
        setSuccess( /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.success, {
          values: {
            email: text
          }
        })));
        setError(null);
      } else {
        setSuccess(null);
        if (response.status === 404) {
          setError( /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.errorNotFound, {
            values: {
              email
            }
          })));
        } else if (/requires single sign-on/.test(text)) {
          setError( /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.errorSSORequired, {
            values: {
              email
            }
          })));
        } else {
          setError( /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.error, {
            values: {
              detail: text
            }
          })));
        }
      }
    }).catch(err => {
      setError( /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.error, {
        values: {
          detail: err.message
        }
      })));
    }).finally(() => {
      setPending(false);
    });
  };
  const errorMessage = error ? /*#__PURE__*/_react.default.createElement("p", {
    className: "status error"
  }, error) : undefined;
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_reactHelmet.Helmet, null, /*#__PURE__*/_react.default.createElement("title", null, intl.formatMessage(messages.title))), errorMessage, /*#__PURE__*/_react.default.createElement("main", null, /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.prompt)), /*#__PURE__*/_react.default.createElement("form", {
    method: "POST",
    onSubmit: handleSubmit
  }, /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement("label", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.email), /*#__PURE__*/_react.default.createElement("input", {
    autoComplete: "email",
    name: "email",
    type: "text"
  }))), /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement("button", {
    className: "send",
    disabled: isPending,
    type: "submit"
  }, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.submit))))));
}
PasswordResetRequestPage.propTypes = propTypes;
PasswordResetRequestPage.defaultProps = defaultProps;
var _default = (0, _reactIntl.injectIntl)(PasswordResetRequestPage);
exports.default = _default;